@@ -7,7 +7,7 @@ PY3 = sys.version_info[0] == 3
 
 if PY3:
     import http.client as httplib
-    from urllib.parse import quote
+    from urllib.parse import quote, urlencode
 
     def b(s):
         return s.encode('utf-8')
@@ -17,11 +17,15 @@ if PY3:
     bytes = bytes
 else:
     import httplib
-    from urllib import quote
+    from urllib import quote, urlencode
 
     def b(s):
         return s
 
     builtin_str = str
-    str = unicode
+    str = unicode  # noqa
     bytes = str
+
+__all__ = [
+    'httplib', 'quote', 'urlencode'
+]
